/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.lsf;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.File;
import java.io.IOException;
import java.util.Vector;
import java.util.Iterator;
import org.glite.apel.core.log.type.EventRecord;

import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Tests to validate the functionality of the EvemtLogParser class.
 */
public class EventLogParserTest extends TestCase {
    private String jobId="813158";
    private String submitHost = "ce102";
    private String jobName = jobId;
    private String user = "cms014";
    private String group = "cms";
    private String memReal = "22484";
    private String memVirtual = "54932";
    private String startTime = "1147008937";
    private String stopTime = "1147039883";
    private String eventDate = "2006-05-07";
    private String eventTime = "22:11:23";
    private int wallSecs = 30946;
    private int cpuSecs = 5;
    private String wallDuration="P8H35M46S";
    private String cpuDuration="P5S";    
    public static junit.framework.Test suite() {
        return new TestSuite(EventLogParserTest.class);
    }

    /**
     * Constructs a dummy event record, returning it as a string.
     */
    private String constructEvent() {
       
       String jobInfo ="\"JOB_FINISH\" \"6.1\" 1147039883 813158 11780 34078746 1 1146788804 0 0 1147008937 \"cms014\" " + 
                       "\"grid_cms\" \"\" \"\" \"\" \"ce102\" \"/pool/grid/cms014\" \"/dev/null\" \"/dev/null\" \"\" \"1146788804.813158\" " + 
                       "0 1 \"lxb6791\" 64 1.0 \"\" \"#! /bin/sh;#;# LSF batch job script built by Globus Job Manager;#;#BSUB -q grid_cms;#BSUB -i " + 
                       "/dev/null;#BSUB -e /dev/null;#BSUB -o /dev/null;#BSUB " + 
                       "-f \"\"/pool/grid/cms014/.lcgjm/globus-cache-export.kH5715/globus-cache-export.kH5715.gp\" 3.440000 2.470000 0 0 -1 0 0 " + 
                       "83736 102058 0 0 0 -1 0 0 0 0 0 -1 \"\" \"default\" 0 1 \"\" \"\" 0 22484 54932 \"\" \"\" \"\" \"\" 0 \"\" 0 \"\" -1 " +
                       "\"/u_CMS/zh_prod/cms_lcg\" \"\"";
        return jobInfo;
    }

    /**
     * Checks the event parser successfully interprets an event log entry.
     */
    public void testParse() {
        String input = constructEvent();
        File tmp = null;
        try {
                // create file unittest.tmp
                tmp = File.createTempFile("unittest", "tmp");
                // write to it
                BufferedWriter out = new BufferedWriter(new FileWriter(tmp));
                out.write(input);
                out.close(); 
                tmp.deleteOnExit();
        } catch (IOException ioe) {
                fail();
        }
        EventLogParser parser = new EventLogParser(tmp, "", "", false);
        parser.parse();
        Vector records = parser.getEventRecords();
        Iterator it = records.iterator();
        while (it.hasNext() ) {
         EventRecord record = (EventRecord) it.next();
         assertEquals(record.getCpuDuration(), cpuDuration);
         assertEquals(record.getCpuDurationSeconds(),Integer.toString(cpuSecs));
         assertEquals(record.getJobName(), jobName);
         assertEquals(record.getLocalUserGroup(), group);
         assertEquals(record.getLocalUserID(), user);
         assertEquals(record.getEventDate(), eventDate);
         assertEquals(record.getEventTime(), eventTime);
         assertEquals(record.getMemoryReal(), memReal);
         assertEquals(record.getMemoryVirtual(), memVirtual);
         assertEquals(record.getStartTimeEpoch(), startTime);
         assertEquals(record.getStopTimeEpoch(), stopTime);
         assertEquals(record.getWallDurationSeconds(), Integer.toString(wallSecs));
         assertEquals(record.getWallDuration(), wallDuration);
         assertEquals(record.getSubmitHost(), submitHost);
        } 
    }
}
